==> web-10.0.0.tgz: package/lib/combo/ComboBasic.js <==
import * as React from "react";
import ComboInp from "./ComboInp";
import * as Immutable from "immutable";
import { SlideBox } from "../animate/index";
import { slideOther, event } from "../util/autoSlideUp";
const wrapComboHC = (Drop, comboType) => { var _a; return _a = class ComBo extends React.PureComponent {
        constructor(prop) {
            super(prop);
            this.eventId = `${new Date().getTime()
                .toString()}-${this.props.field}`;
            this.bindSelectFn = (fn) => {
                this.selectFn = fn;
            };
            this.dropToggle = (e) => {
                slideOther(e.nativeEvent, this.eventId);
                this.setState((pre) => ({
                    drop: !pre.drop,
                }));
            };
            this.documentClickFn = () => {
                this.setState({
                    drop: false,
                });
            };
            this.initSelect = (selecteds) => {
                const { renderCallback } = this.props;
                this.setState({
                    selected: selecteds
                }, () => {
                    if (renderCallback) {
                        const { field, clickCallback } = this.props;
                        const { selected } = this.state;
                        clickCallback(selected.toJS(), field);
                    }
                });
            };
            this.changeSelect = (selecteds, node) => {
                const { clickCallback, field, multiply } = this.props;
                this.setState((pre) => ({
                    selected: selecteds,
                    drop: !multiply ? false : pre.drop
                }), () => {
                    const { selected } = this.state;
                    clickCallback(selected.toJS(), field, node);
                });
            };
            this.state = this.initState();
            this.initFieldObj(prop);
            const { maxHeight } = prop;
            this.dropStyle = { maxHeight: maxHeight, };
        }
        initFieldObj(prop) {
            const { idField, textField, multiply, itemIcon, defaultVal, noSearch, field, clickOrCheckForbid, } = prop;
            const common = {
                idField: idField,
                textField: textField,
                multiply,
                noSearch,
                itemIcon,
                defaultVal: `${defaultVal}`,
                clickOrCheckForbid,
                field
            };
            if (comboType === "list") {
                this.filedObj = Immutable.fromJS(common);
            }
            else {
                const { childField, } = prop;
                let treeField = Object.assign(common, { childField, noSearch });
                this.filedObj = Immutable.fromJS(treeField);
            }
        }
        initState() {
            return {
                drop: false,
                selected: Immutable.List([]),
            };
        }
        componentDidMount() {
            event.on(this.eventId, this.documentClickFn);
        }
        componentWillUnmount() {
            event.remove(this.eventId);
        }
        renderCombox() {
            const { formatterVal, noIcon, multiply, tit, width, data, dropWidth, noRequire, formatterDropItem, directionUp, ableClear, initComboVal, disabled } = this.props;
            const { selected, drop } = this.state;
            const palceholder = tit ? tit : multiply ? "多选" : "单选";
            const activeName = drop ? "autoSlideUp" : "";
            return (React.createElement("div", { className: "g-combo " + activeName, "data-event": this.eventId, style: { width: width, } },
                React.createElement(ComboInp, { drop: drop, tit: palceholder, selected: selected, formatterVal: formatterVal, slideFn: this.dropToggle, disabled: disabled, noicon: noIcon, ableClear: ableClear, noRequire: noRequire, clearFn: this.selectFn }),
                React.createElement("div", { className: `m-drop ${directionUp ? "direction-up" : ""}`, style: dropWidth ? { width: dropWidth } : undefined },
                    React.createElement(SlideBox, { slide: drop, directionUp: directionUp },
                        React.createElement(Drop, { filedObj: this.filedObj, data: data, disabled: disabled, changeSelect: this.changeSelect, selected: selected, dropStyle: this.dropStyle, initSelect: this.initSelect, initComboVal: initComboVal, formatterDropItem: formatterDropItem, clickMethod: this.bindSelectFn })))));
        }
        render() {
            const { children } = this.props;
            return children ? (React.createElement("div", { className: "m-flex-center" },
                React.createElement("span", { className: "lab-tit" }, children),
                this.renderCombox())) : this.renderCombox();
        }
    },
    _a.defaultProps = {
        idField: "id",
        textField: "text",
        childField: "children",
        width: 240,
        maxHeight: 240,
        defaultVal: "",
        clickOrCheckForbid: function () {
            return false;
        }
    },
    _a; };
export default wrapComboHC;

==> web-11.0.2.tgz: package/lib/combo/ComboBasic.js <==
import * as React from "react";
import ComboInp from "./ComboInp";
import * as Immutable from "immutable";
import { SlideBox } from "../animate/index";
import { slideOther, event } from "../util/autoSlideUp";
const wrapComboHC = (Drop, comboType) => { var _a; return _a = class ComBo extends React.PureComponent {
        constructor(prop) {
            super(prop);
            this.eventId = `${new Date().getTime()
                .toString()}-${this.props.field}`;
            this.bindSelectFn = (fn) => {
                this.selectFn = fn;
            };
            this.dropToggle = () => {
                slideOther(this.eventId);
                this.setState((pre) => ({
                    drop: !pre.drop,
                }));
            };
            this.documentClickFn = () => {
                this.setState({
                    drop: false,
                });
            };
            this.initSelect = (selecteds) => {
                const { renderCallback } = this.props;
                this.setState({
                    selected: selecteds
                }, () => {
                    if (renderCallback) {
                        const { field, clickCallback } = this.props;
                        const { selected } = this.state;
                        clickCallback(selected.toJS(), field);
                    }
                });
            };
            this.changeSelect = (selecteds, node) => {
                const { clickCallback, field, multiply, noautoFold } = this.props;
                this.setState((pre) => ({
                    selected: selecteds,
                    drop: !multiply && !noautoFold ? false : pre.drop
                }), () => {
                    const { selected } = this.state;
                    clickCallback(selected.toJS(), field, node);
                });
            };
            this.state = this.initState();
            this.initFieldObj(prop);
            const { maxHeight } = prop;
            this.dropStyle = { maxHeight: maxHeight, };
        }
        initFieldObj(prop) {
            const { idField, textField, multiply, itemIcon, defaultVal, noSearch, field, clickOrCheckForbid, } = prop;
            const common = {
                idField: idField,
                textField: textField,
                multiply,
                noSearch,
                itemIcon,
                defaultVal: `${defaultVal}`,
                clickOrCheckForbid,
                field
            };
            if (comboType === "list") {
                this.filedObj = Immutable.fromJS(common);
            }
            else {
                const { childField, } = prop;
                let treeField = Object.assign(common, { childField, noSearch });
                this.filedObj = Immutable.fromJS(treeField);
            }
        }
        initState() {
            return {
                drop: false,
                selected: Immutable.List([]),
            };
        }
        componentDidMount() {
            event.on(this.eventId, this.documentClickFn);
        }
        componentWillUnmount() {
            event.remove(this.eventId);
        }
        renderComboInp() {
            const { formatterVal, noIcon, multiply, tit, noRequire, ableClear, disabled, field, editFn } = this.props;
            const { selected, drop } = this.state;
            const palceholder = tit ? tit : multiply ? "多选" : "单选";
            const { formatterComboInp, defaultEditVal } = this.props;
            return formatterComboInp ? formatterComboInp({
                drop,
                selected,
                slideFn: this.dropToggle,
                clearFn: this.selectFn
            }) : (React.createElement(ComboInp, { drop: drop, tit: palceholder, editFn: editFn, field: field, selected: selected, formatterVal: formatterVal, defaultEditVal: defaultEditVal, slideFn: this.dropToggle, disabled: disabled, noicon: noIcon, ableClear: ableClear, noRequire: noRequire, clearFn: this.selectFn }));
        }
        renderCombox() {
            const { width, data, dropWidth, formatterDropItem, directionUp, initComboVal, disabled } = this.props;
            const { selected, drop } = this.state;
            const activeName = drop ? "autoSlideUp" : "";
            return (React.createElement("div", { className: "g-combo " + activeName, "data-event": this.eventId, style: { width: width, } },
                this.renderComboInp(),
                React.createElement("div", { className: `m-drop ${directionUp ? "direction-up" : ""}`, style: dropWidth ? { width: dropWidth } : undefined },
                    React.createElement(SlideBox, { slide: drop, directionUp: directionUp },
                        React.createElement(Drop, { filedObj: this.filedObj, data: data, disabled: disabled, changeSelect: this.changeSelect, selected: selected, dropStyle: this.dropStyle, initSelect: this.initSelect, initComboVal: initComboVal, formatterDropItem: formatterDropItem, clickMethod: this.bindSelectFn })))));
        }
        render() {
            const { children } = this.props;
            return children ? (React.createElement("div", { className: "m-flex-center" },
                React.createElement("span", { className: "lab-tit" }, children),
                this.renderCombox())) : this.renderCombox();
        }
    },
    _a.defaultProps = {
        idField: "id",
        textField: "text",
        childField: "children",
        width: 240,
        maxHeight: 240,
        defaultVal: "",
        clickOrCheckForbid: function () {
            return false;
        }
    },
    _a; };
export default wrapComboHC;
